////  BarcodeApi.h
////  Created by Robin on 2016. 4. 22..

#import "AsReaderDevice.h"

typedef NS_ENUM(NSInteger, OCRType){
    OCR_TYPENONE,
    OCR_TYPEA,
    OCR_TYPEB,
    OCR_TYPEAB
};

typedef NS_ENUM(NSInteger, OCRSettingSequence){
    OCR_SEQ_NONE,
    OCR_SEQ_1,
    OCR_SEQ_2,
    OCR_SEQ_3
};

typedef NS_ENUM(NSInteger, CODEId){
    CODEID_NONE,
    CODEID_AIM,
    CODEID_SYMBOL
};

@interface AsReaderBarcodeDevice : AsReaderDevice

+ (instancetype)sharedInstance;

/**
 *  @brief      Start Barcode Scan (Presentation Mode) for M24D
 *  @details    Start a tag (Barcode) read operation,
 *  @return     YES
 */
- (BOOL)startAutoScan;

- (BOOL)reset;


/**
 *  @brief      Start Barcode Scan
 *  @details    Start a tag (Barcode) read operation,
 *  @return     YES
 */
- (BOOL)startScan;


/**
 *  @brief      Send the "Stop Scan" command to the reader
 *  @details    Stop a read operation
 *  @return     YES
 */
- (BOOL)stopScan;

/**
 *  @brief      Barcode module Factory reset
 *  @details    Reset Barcode module to Factory settings
 *  @return     YES
 */
- (BOOL)doFactoryReset;

/**
 *  @brief      Send the "Barcode Setting" command to the reader
 *  @details    Set illumination
 *  @param      sendData : To turn illumination on, sendData value is converted from String "SCNAIM2." to Byte
 : To turn illumination off, sendData value is converted from String "SCNAIM0." to Byte
 *  @return     YES
 */
- (BOOL)sendBarcodeSettingData:(NSData*)sendData;
- (BOOL)setCustomPrefix:(NSString *)prefix;
- (BOOL)setDisableCustomPrefix;
- (BOOL)setCustomSuffix:(NSString *)suffix;
- (BOOL)setDisableCustomSuffix;

/**
 *  @brief      Send the "Barcode Setting" command about SymbologyPrefix to the reader
 *  @details    setSymbologyPrefix
 *  @return     YES (Sucess) / NO (Not suport fuction or Not Selected Barcode)
 */
- (BOOL)setSymbologyPrefix;
- (BOOL)setDisableSymbologyPrefix;
- (BOOL)setBarcodeEngineUserCommand:(NSString *)command;

#pragma MARK

//API for M24D
/**
 *  @brief      Start Barcode Scan (Presentation Mode) for M24D
 *  @details    Start a tag (Barcode) read operation,
 *  @return     YES
 */

- (BOOL)setSleepBeep: (BOOL)isOn;

- (BOOL)setCodeID: (CODEId)type isBeepOn:(BOOL)isBeepOn;

- (BOOL)setSleepTime: (int)time;

- (BOOL)setOCRType: (OCRType)type isBeepOn:(BOOL)isBeepOn;

- (BOOL)setAndroidHIDEnable: (BOOL)isOn;

- (BOOL)setiOSHIDEnable: (BOOL)isOn;

- (BOOL)setPresentationMode: (BOOL)isOn isBeepOn:(BOOL)isBeepOn;

- (BOOL)getCodeID;

- (BOOL)getSleepTime;

- (BOOL)getOCR;

- (BOOL)getHID;

- (BOOL)getSymbologies;

- (BOOL)setSsiParamWithData:(NSData *)symbolData beepOn:(BOOL)beepOn;

- (BOOL)setSsiParamWithDictionary:(NSDictionary*)symbologies beepOn:(BOOL)beepOn;

- (BOOL)getPresentationMode;

- (BOOL)getAutoLaunch;

- (BOOL)setAutoLaunch:(BOOL)enable bundleId:(NSString*) bundleId;

- (BOOL)getSecurity;
//- (void)test;
@end
